// Antarctica Carbon2Color SCD30 
// Visualizes atmospheric CO2 in three colors: green, orange and red. 
// Nicole Bakker 
// Fab Academy 2021
  

// Based on sample code: Basic demo for readings from Adafruit SCD30

#include <Adafruit_SCD30.h>

Adafruit_SCD30  scd30;

#include <tinyNeoPixel.h>

tinyNeoPixel strip = tinyNeoPixel(32, 8, NEO_GRB + NEO_KHZ800);


#define PIN B0
#define PIN B1
#define PIN 8

const int low = 700;
const int high = 1000;

void setup() {

  // CO2 sensor setup 

  Serial.begin(115200);
  while (!Serial) delay(10);     // will pause Zero, Leonardo, etc until serial console opens

  Serial.println("Adafruit SCD30 test!");

  // Try to initialize!
  if (!scd30.begin()) {
    Serial.println("Failed to find SCD30 chip");
    while (1) { delay(10); }
  }
  Serial.println("SCD30 Found!");


  // if (!scd30.setMeasurementInterval(10)){
  //   Serial.println("Failed to set measurement interval");
  //   while(1){ delay(10);}
  // }
  Serial.print("Measurement Interval: "); 
  Serial.print(scd30.getMeasurementInterval()); 
  Serial.println(" seconds");


// Neopixel setup

  strip.begin();
  strip.show(); // Initialize all pixels to 'off'

}//void setup

  
void loop() {

  if (scd30.dataReady()) {
    Serial.println("Data available!");

    if (!scd30.read()){ Serial.println("Error reading sensor data"); return; }

    // Blink LED1 blue to indicate that the sensor is on
    colorWipe(strip.Color(0, 0, 255), 50); // Blue
    delay(100);

 
    // CO2 sensor standard 

    Serial.print("Temperature: ");
    Serial.print(scd30.temperature);
    Serial.println(" degrees C");
    
    Serial.print("Relative Humidity: ");
    Serial.print(scd30.relative_humidity);
    Serial.println(" %");
    
    Serial.print("CO2: ");
    Serial.print(scd30.CO2, 3);
    Serial.println(" ppm");
    Serial.println("");


    // Activate LED at CO2 levels
  
    if (scd30.CO2 < low) { //low - blink green LED
        Serial.println("CO2 below 700ppm");
        colorWipe(strip.Color(0, 255, 0), 50); // Green
    } else if (scd30.CO2 > high) { //high - blink red LED 
        Serial.println("CO2 above 1000ppm");
        colorWipe(strip.Color(255, 0, 0), 50); // Red
    } else { //medium - blink orange LED
        Serial.println("CO2 in between 700-1000 ppm");
        colorWipe(strip.Color(255, 70, 0), 50); // Orange   
    }//else
    
    // regular code
        
  } else {
        //Serial.println("No data");
  }//else

  delay(100);
}//void loop


//////////////////// Color functions //////////////////////

 // Fill the dots one after the other with a color
void colorWipe(uint32_t c, uint8_t wait) {
  for (uint16_t i = 0; i < strip.numPixels(); i++) {
    strip.setPixelColor(i, c);
    strip.show();
    delay(wait);
  }//for i
}//void color 
